.. _electrondens:

#######################
Electron Density Models
#######################

This page documents the implemented models for the electron density in different astrophysical environments
available in gammaALPs:

* :ref:`icm_nel`: Electron density model for intra-cluster medium.

* :ref:`jet_nel`: Electron density model for jets of active galactic nuclei.

.. toctree::
   :hidden:
   :maxdepth: 1

   icm_nel
   jet_nel
